@@ -153,8 +153,8 @@ class ANDiscord(HTMLRequestHandler):
         if head:
             return
         return await self.render(
-            "pages/ask_for_redirect.html",
-            referrerpolicy=None,
+            "pages/redirect.html",
+            send_referrer=True,
             redirect_url=invite,
             from_url=None,
             discord=True,
