@@ -2,5 +2,5 @@
 (()=>{const resultsList=elById("search-results");const searchForm=elById("search-form");const searchInput=elById("search-input");function displayResults(results){resultsList.innerHTML="";for(const result of results){const resultElement=d.createElement("li");resultElement.setAttribute("score",String(result["score"]));resultElement.innerHTML=(`<a rel="noreferrer" href='${fixHref(result.url)}'>`
 +`${result.title}</a> ${result.description}`);resultsList.appendChild(resultElement);}}
 w.PopStateHandlers["search"]=(event)=>{searchInput.value=event.state["query"];displayResults(event.state["results"]);}
-searchForm.action="javascript:void(0)";searchForm.onsubmit=()=>{get("/api/suche","q="+searchInput.value,(data)=>{displayResults(data);setURLParam("q",searchInput.value,{"query":searchInput.value,"results":data},"search",true);})}})();
+searchForm.action="javascript:void(0)";searchForm.onsubmit=()=>get("/api/suche","q="+searchInput.value,(data)=>{displayResults(data);setURLParam("q",searchInput.value,{"query":searchInput.value,"results":data},"search",true);});})();
 // @license-end
